@@ -10,11 +10,13 @@ from queue import Queue
 import traceback
 from redflagbpm.Services import Service, DocumentService, Context, ResourceService, ExecutionService, RuntimeService
 
+
 class ServiceError(Exception):
-    def __init__(self, body:dict):
+    def __init__(self, body: dict):
         super().__init__(body.get("error"))
         self.trace = body.get("trace")
 
+
 class BPMService:
     service: Service
     context: Context
@@ -89,12 +91,14 @@ class BPMService:
             body = {"reply": body}
         self.__eb_calls.send(address=addr, headers=headers, body=body)
 
-    def fail(self, message: str = None, address=None, headers=None):
+    def fail(self, message: str = None, do_quit=True, address=None, headers=None):
         if message is None:
-            message=traceback.format_exc()
+            message = traceback.format_exc()
         addr = self.__getAddress(address)
-        body = {"error": message, "succeeded":False}
+        body = {"error": message, "succeeded": False}
         self.__eb_calls.send(address=addr, headers=headers, body=body)
+        if do_quit:
+            quit()
 
     def call(self, address, body=None, headers=None):
         ret = self.send(address, headers, body)
@@ -123,7 +127,7 @@ class BPMService:
     def __run_external(self, address, handler):
         my_env = os.environ.copy()
         my_env["BPM_EVENT_BUS_REPLY"] = address["replyAddress"]
-        subprocess.Popen(sys.executable+" "+handler, env=my_env, shell=True)
+        subprocess.Popen(sys.executable + " " + handler, env=my_env, shell=True)
 
     def register_handler(self, address, handler):
         if isinstance(handler, str):
